// Copyright (c) 2002 Cunningham & Cunningham, Inc.
// Released under the terms of the GNU General Public License version 2 or later.

package eg.music;

import java.util.*;
import java.io.*;
import java.text.*;


public class Music {

    static Music library[] = {};
    static Music looking = null;
    static Music playing = null;

    public String title;
    public String artist;
    public String album;
    public String genre;
    public long size;
    public int time;
    public int trackNumber;
    public int trackCount;
    public int year;
    public Date date;
    public transient boolean selected = false;


    // Accessors ////////////////////////////////

    public String track() {
        return trackNumber + " of " + trackCount;
    }

    public double time() {
        return Math.round(time / 0.6) / 100.0;
    }

    public String toString() {
        if (title != null) {
            return title;
        } else {
            return super.toString();
        }
    }


    // Factory //////////////////////////////////

    static void load(String name) {
        Music buffer[] = new Music[1000];
        int count;
        try {
            BufferedReader in = new BufferedReader(new FileReader(name));
            in.readLine(); // skip column headings
            for (count=0; count<buffer.length && in.ready(); count++) {
                buffer[count]=parse(in.readLine());
            }
            in.close();
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }
        library = new Music[count];
        for (int i=0; i<count; i++) {
            library[i] = buffer[i];
        }
        return;
    }

    static DateFormat dateFormat = new SimpleDateFormat("M/d/yy h:mm a");

    static Music parse(String string) throws ParseException {
        Music m = new Music();
        StringTokenizer t = new StringTokenizer(string,"\t");
        m.title =       t.nextToken();
        m.artist =      t.nextToken();
        m.album =       t.nextToken();
        m.genre =       t.nextToken();
        m.size =        Long.parseLong(t.nextToken());
        m.time =        Integer.parseInt(t.nextToken());
        m.trackNumber = Integer.parseInt(t.nextToken());
        m.trackCount =  Integer.parseInt(t.nextToken());
        m.year =        Integer.parseInt(t.nextToken());
        m.date =        dateFormat.parse(t.nextToken());
        return m;
    }


    // Library //////////////////////////////////

    static void select(Music m) {
        looking = m;
    }

    static void play(Music m) {
        // nothing yet
    }

    static void findAll() {
        for (int i=0; i<library.length; i++) {
            library[i].selected = true;
        }
    }

    static void findArtist(String a) {
        for (int i=0; i<library.length; i++) {
            library[i].selected = library[i].artist.equals(a);
        }
    }

    static void findAlbum(String a) {
        for (int i=0; i<library.length; i++) {
            library[i].selected = library[i].album.equals(a);
        }
    }

    static void findGenre(String a) {
        for (int i=0; i<library.length; i++) {
            library[i].selected = library[i].genre.equals(a);
        }
    }

    static void findYear(int a) {
        for (int i=0; i<library.length; i++) {
            library[i].selected = library[i].year == a;
        }
    }

    static int displayCount() {
        int count = 0;
        for (int i=0; i<library.length; i++) {
            count += (library[i].selected ? 1 : 0);
        }
        return count;
    }

    static Music[] displayContents () {
        Music displayed[] = new Music[displayCount()];
        for (int i=0, j=0; i<library.length; i++) {
            if (library[i].selected) {
                displayed[j++] = library[i];
            }
        }
        return displayed;
    }



}
